# python example Package

This is a simple example package.
https://github.com/pypa/sampleproject.git

https://www.geeksforgeeks.org/what-is-setup-py-in-python/#  
https://packaging.python.org/en/latest/guides/installing-using-linux-tools/
https://packaging.python.org/en/latest/tutorials/packaging-projects/  
```
pip install setuptools 
python setup.py sdist bdist_wheel
python setup.py sdist
pip install sdk
```